Skip to contents

Get the names of the supported software defined in the default mapping schema

Usage

softwareMapping()

Value

A character vector with the names of the supported software.

See also

Other name translation functions: guessSource(), nameMapping(), softwareMappingSchema(), translate()

Author

Gabriele Tomè

Examples


softwareMapping()
#>  [1] "RforMassSpectrometry" "MS-Dial"              "MetaboScape"         
#>  [4] "mzMine"               "mzTab-M"              "xcms"                
#>  [7] "Sirius <v6.0"         "Sirius >v6.0"         "MetFamily QFeatures" 
#> [10] "Ontology Term"