Get the names of the supported software defined in the default mapping schema
See also
Other name translation functions:
guessSource(),
nameMapping(),
softwareMappingSchema(),
translate()
Get the names of the supported software defined in the default mapping schema
Other name translation functions:
guessSource(),
nameMapping(),
softwareMappingSchema(),
translate()